pub fn passive_gcd_ms(query: PassiveQuery<'_>, initial: i32) -> i32Expand description
Global cooldown after selected passive flat and percentage modifiers.
pub fn passive_gcd_ms(query: PassiveQuery<'_>, initial: i32) -> i32Global cooldown after selected passive flat and percentage modifiers.